@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::WordListModules;
 
-our $VERSION = "0.050"; # VERSION
+our $VERSION = 0.051; # VERSION
 
 our $results = [
   [
@@ -8,20 +8,53 @@ our $results = [
     "OK",
     [
       {
-        errors => 2.9e-05,
-        mod_overhead_time => 1.1,
-        participant => "WordList::ID::KBBI",
+        errors => 2.8e-05,
+        mod_overhead_time => 1,
+        participant => "WordList::EN::Enable",
+        proc_private_dirty_size => 944,
+        proc_rss_size => 4.3,
+        proc_size => 16,
+        samples => 20,
+        time => 7.1,
+        vs_slowest => 1,
+      },
+      {
+        errors => 3.4e-05,
+        mod_overhead_time => 1,
+        participant => "WordList::Phrase::ID::Proverb::KBBI",
+        proc_private_dirty_size => 920,
+        proc_rss_size => 4.3,
+        proc_size => 16,
+        samples => 25,
+        time => 7.1,
+        vs_slowest => 1,
+      },
+      {
+        errors => 3.3e-05,
+        mod_overhead_time => 1,
+        participant => "WordList::EN::SGB",
+        proc_private_dirty_size => 948,
+        proc_rss_size => 4.4,
+        proc_size => 16,
+        samples => 24,
+        time => 7.1,
+        vs_slowest => 1,
+      },
+      {
+        errors => 1.3e-05,
+        mod_overhead_time => 0.9,
+        participant => "WordList::EN::CountryNames::SingleWord",
         proc_private_dirty_size => 952,
         proc_rss_size => 4.3,
         proc_size => 16,
-        samples => 21,
+        samples => 20,
         time => 7,
         vs_slowest => 1,
       },
       {
-        errors => 1.9e-05,
-        mod_overhead_time => 1.1,
-        participant => "WordList::Phrase::EN::Proverb::TWW",
+        errors => 2.4e-05,
+        mod_overhead_time => 0.9,
+        participant => "WordList::ID::KBBI",
         proc_private_dirty_size => 948,
         proc_rss_size => 4.2,
         proc_size => 16,
@@ -30,80 +63,58 @@ our $results = [
         vs_slowest => 1,
       },
       {
-        errors => 2.1e-05,
-        mod_overhead_time => 1,
-        participant => "WordList::Phrase::ID::Proverb::KBBI",
-        proc_private_dirty_size => 916,
+        errors => 3e-05,
+        mod_overhead_time => 0.9,
+        participant => "WordList::Phrase::EN::Proverb::TWW",
+        proc_private_dirty_size => 948,
         proc_rss_size => 4.3,
         proc_size => 16,
         samples => 20,
+        time => 7,
+        vs_slowest => 1,
+      },
+      {
+        errors => 1.8e-05,
+        mod_overhead_time => 0.800000000000001,
+        participant => "WordList::EN::CountryNames",
+        proc_private_dirty_size => 948,
+        proc_rss_size => 4.3,
+        proc_size => 16,
+        samples => 20,
+        time => 6.9,
+        vs_slowest => 1,
+      },
+      {
+        errors => 2.8e-05,
+        mod_overhead_time => 0.800000000000001,
+        participant => "WordListC::Password::10Million::Top100000",
+        proc_private_dirty_size => 920,
+        proc_rss_size => 4.2,
+        proc_size => 16,
+        samples => 21,
         time => 6.9,
         vs_slowest => 1,
       },
       {
         errors => 3.4e-05,
-        mod_overhead_time => 1,
-        participant => "WordList::EN::CountryNames::SingleWord",
-        proc_private_dirty_size => 940,
+        mod_overhead_time => 0.800000000000001,
+        participant => "WordListC::Password::10Million::Top1000000",
+        proc_private_dirty_size => 844,
         proc_rss_size => 4.2,
         proc_size => 16,
-        samples => 22,
+        samples => 27,
         time => 6.9,
         vs_slowest => 1,
       },
       {
-        errors => 3.2e-05,
-        mod_overhead_time => 0.899999999999999,
-        participant => "WordList::EN::CountryNames",
-        proc_private_dirty_size => 944,
-        proc_rss_size => 4.3,
-        proc_size => 16,
-        samples => 21,
-        time => 6.8,
-        vs_slowest => 1,
-      },
-      {
-        errors => 3.1e-05,
-        mod_overhead_time => 0.8,
-        participant => "WordList::EN::Enable",
-        proc_private_dirty_size => 944,
-        proc_rss_size => 4.3,
-        proc_size => 16,
-        samples => 30,
-        time => 6.7,
-        vs_slowest => 1,
-      },
-      {
-        errors => 3.2e-05,
-        mod_overhead_time => 0.8,
-        participant => "WordList::EN::SGB",
-        proc_private_dirty_size => 940,
-        proc_rss_size => 4.2,
-        proc_size => 16,
-        samples => 30,
-        time => 6.7,
-        vs_slowest => 1,
-      },
-      {
-        errors => 1.5e-05,
-        mod_overhead_time => 0.8,
-        participant => "WordListC::Password::SecLists::10Million::Top100000",
-        proc_private_dirty_size => 844,
-        proc_rss_size => 4.1,
-        proc_size => 16,
-        samples => 20,
-        time => 6.7,
-        vs_slowest => 1,
-      },
-      {
-        errors => 2.9e-05,
+        errors => 2.8e-05,
         mod_overhead_time => 0,
         participant => "perl -e1 (baseline)",
-        proc_private_dirty_size => 940,
+        proc_private_dirty_size => 948,
         proc_rss_size => 4.3,
         proc_size => 16,
-        samples => 23,
-        time => 5.9,
+        samples => 20,
+        time => 6.1,
         vs_slowest => 1.2,
       },
     ],
@@ -229,7 +240,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2658.752,
+                                              speed                        => 2591.247,
                                               stepping                     => 4,
                                             },
                                             {
@@ -345,7 +356,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2666.613,
+                                              speed                        => 2589.794,
                                               stepping                     => 4,
                                             },
                                             {
@@ -461,7 +472,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2443.676,
+                                              speed                        => 2568.774,
                                               stepping                     => 4,
                                             },
                                             {
@@ -577,30 +588,31 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2574.499,
+                                              speed                        => 2561.853,
                                               stepping                     => 4,
                                             },
                                           ],
-      "func.elapsed_time"              => 1.88844013214111,
+      "func.elapsed_time"              => 2.01031684875488,
       "func.module_startup"            => 1,
       "func.module_versions"           => {
-                                            "__PACKAGE__"                                         => "1.040",
-                                            "Bencher::Scenario::WordListModules"                  => undef,
-                                            "Benchmark::Dumb"                                     => 0.111,
-                                            "Devel::Platform::Info"                               => 0.16,
-                                            "perl"                                                => "v5.26.1",
-                                            "Sys::Info"                                           => 0.78,
-                                            "WordList::EN::CountryNames"                          => 0.04,
-                                            "WordList::EN::CountryNames::SingleWord"              => 0.04,
-                                            "WordList::EN::Enable"                                => 0.03,
-                                            "WordList::EN::SGB"                                   => 0.03,
-                                            "WordList::ID::KBBI"                                  => 0.04,
-                                            "WordList::Phrase::EN::Proverb::TWW"                  => 0.03,
-                                            "WordList::Phrase::ID::Proverb::KBBI"                 => 0.03,
-                                            "WordListC::Password::SecLists::10Million::Top100000" => 0.001,
+                                            "__PACKAGE__" => "1.040",
+                                            "Bencher::Scenario::WordListModules" => undef,
+                                            "Benchmark::Dumb" => 0.111,
+                                            "Devel::Platform::Info" => 0.16,
+                                            "perl" => "v5.26.1",
+                                            "Sys::Info" => 0.78,
+                                            "WordList::EN::CountryNames" => 0.04,
+                                            "WordList::EN::CountryNames::SingleWord" => 0.04,
+                                            "WordList::EN::Enable" => 0.03,
+                                            "WordList::EN::SGB" => 0.03,
+                                            "WordList::ID::KBBI" => 0.04,
+                                            "WordList::Phrase::EN::Proverb::TWW" => 0.03,
+                                            "WordList::Phrase::ID::Proverb::KBBI" => 0.03,
+                                            "WordListC::Password::10Million::Top100000" => 0.001,
+                                            "WordListC::Password::10Million::Top1000000" => 0.001,
                                           },
       "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
-      "func.permute"                   => ["perl", ["perl"], "participant", [0 .. 8]],
+      "func.permute"                   => ["perl", ["perl"], "participant", [0 .. 9]],
       "func.platform_info"             => {
                                             archname => "x86_64",
                                             codename => "sylvia",
@@ -626,13 +638,13 @@ our $results = [
                                           },
       "func.precision"                 => 0.005,
       "func.scenario_module"           => "Bencher::Scenario::WordListModules",
-      "func.scenario_module_md5sum"    => "a7c92794773877d57ab6f50976dbec8b",
-      "func.scenario_module_mtime"     => 1519115828,
-      "func.scenario_module_sha1sum"   => "6be938537615e92d4b30029e93895a6c585aaf06",
-      "func.scenario_module_sha256sum" => "f051c35dbbf32006fb329d99ae8db8bbb23e7df3296b1410d295a14c94206385",
-      "func.time_end"                  => 1519116019.46781,
+      "func.scenario_module_md5sum"    => "ec3c922e941d09e5b0765612dd6f5870",
+      "func.scenario_module_mtime"     => 1519120319,
+      "func.scenario_module_sha1sum"   => "020acf7f3f201f8541daa9f971acf896103bc6de",
+      "func.scenario_module_sha256sum" => "20e7d9edb13093e59191871c68be797085ef38521eeace4e70c4adf9dcc768dd",
+      "func.time_end"                  => 1519120412.6244,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1519116017.57937,
+      "func.time_start"                => 1519120410.61409,
       "table.field_aligns"             => [
                                             "left",
                                             "left",
